==> xscorch_0.1.14.orig.tar.gz: xscorch-0.1.14/ssound/ssoundnull.c <==
/* $Header: /fridge/cvs/xscorch/ssound/ssoundnull.c,v 1.2 2001/04/07 19:49:48 justins Exp $ */
/*
   
   xscorch - ssoundnull.c     Copyright(c) 2001,2000 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/
    
   xscorch null sound driver
   

   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation; either version 2 of the License, or 
   (at your option) any later version.

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#include <ssound.h>



void sc_sound_init(void) {
/* sc_sound_init */
   
}



sc_sound *sc_sound_new(int enable, int hqmixer) {

   return(NULL);
   
}



void sc_sound_config(sc_sound **s, int enable, int hqmixer) {

}



void sc_sound_free(sc_sound **s) {

   if(s == NULL || *s == NULL) return;
   free(*s);
   *s = NULL;
   
}



void sc_sound_start(sc_sound *s, sc_sound_music id) {

}



void sc_sound_update(sc_sound *s) {
   
}



void sc_sound_stop(sc_sound *s) {

}



void sc_sound_pause(sc_sound *s) {

}



void sc_sound_unpause(sc_sound *s) {

}

==> xscorch-0.2.0.tar.gz: xscorch-0.2.0/ssound/ssoundnull.c <==
/* $Header: /fridge/cvs/xscorch/ssound/ssoundnull.c,v 1.4 2004/02/26 06:34:57 justins Exp $ */
/*
   
   xscorch - ssoundnull.c     Copyright(c) 2001,2000 Justin David Smith
   justins(at)chaos2.org      http://chaos2.org/
    
   xscorch null sound driver
   

   This program is free software; you can redistribute it and/or modify 
   it under the terms of the GNU General Public License as published by 
   the Free Software Foundation, version 2 of the License ONLY. 

   This program is distributed in the hope that it will be useful, 
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
#include <ssound.h>



void sc_sound_init(void) {
/* sc_sound_init */
   
}



sc_sound *sc_sound_new(unused int enable, unused int hqmixer) {

   return(NULL);
   
}



void sc_sound_config(unused sc_sound **s, unused int enable, unused int hqmixer) {

}



void sc_sound_free(sc_sound **s) {

   if(s == NULL || *s == NULL) return;
   free(*s);
   *s = NULL;
   
}



void sc_sound_start(unused sc_sound *s, unused sc_sound_music id) {

}



void sc_sound_update(unused sc_sound *s) {
   
}



void sc_sound_stop(unused sc_sound *s) {

}



void sc_sound_pause(unused sc_sound *s) {

}



void sc_sound_unpause(unused sc_sound *s) {

}
